function divdiff= metodo2 (f, x)
%METODO: calcolo differenze divise
%
% divdiff = metodo (f, x)
%
% Dati di ingresso:
%   f:      funzione (inline function)
%   x:     vettore delle ascisse
%
% Dati di uscita:
%   divdiff: vettore delle differenze divise di f in x

if size(x,1) < size(x,2)
    x=x';
end

f_values=feval(f,x);

divdiff=f_values;
m=length(x);

for i=2:m
    for j=m:-1:i
        divdiff(j)=(divdiff(j)-divdiff(j-1))/(x(j)-x(j-i+1));
    end
end

